@@ -17,7 +17,6 @@
 
 import random
 import sys
-import threading
 import time
 
 from eventlet import event
@@ -77,53 +76,6 @@ def _safe_wrapper(f, kind, func_name):
     return func
 
 
-def _Event():
-    if eventletutils.is_monkey_patched('thread'):
-        return _ThreadingEvent()
-    else:
-        return _GreenEvent()
-
-
-class _ThreadingEvent(object):
-    def __init__(self):
-        self._abort = threading.Event()
-
-    def is_running(self):
-        return not self._abort.is_set()
-
-    def clear(self):
-        self._abort.clear()
-
-    def wait(self, timeout):
-        self._abort.wait(timeout)
-
-    def stop(self):
-        self._abort.set()
-
-    def done(self):
-        pass
-
-
-class _GreenEvent(object):
-    def __init__(self):
-        self._running = False
-
-    def is_running(self):
-        return self._running
-
-    def clear(self):
-        self._running = True
-
-    def wait(self, timeout):
-        greenthread.sleep(timeout)
-
-    def stop(self):
-        self._running = False
-
-    def done(self):
-        self._running = False
-
-
 class LoopingCallBase(object):
     _KIND = _("Unknown looping call")
 
@@ -136,24 +88,24 @@ class LoopingCallBase(object):
         self.f = f
         self._thread = None
         self.done = None
-        self._event = _Event()
+        self._abort = eventletutils.EventletEvent()
 
     @property
     def _running(self):
-        return self._event.is_running()
+        return not self._abort.is_set()
 
     def stop(self):
-        self._event.stop()
+        if self._running:
+            self._abort.set()
 
     def wait(self):
         return self.done.wait()
 
     def _on_done(self, gt, *args, **kwargs):
         self._thread = None
-        self._event.done()
 
     def _sleep(self, timeout):
-        self._event.wait(timeout)
+        self._abort.wait(timeout)
 
     def _start(self, idle_for, initial_delay=None, stop_on_exception=True):
         """Start the looping
@@ -171,13 +123,18 @@ class LoopingCallBase(object):
         if self._thread is not None:
             raise RuntimeError(self._RUN_ONLY_ONE_MESSAGE)
         self.done = event.Event()
-        self._event.clear()
+        self._abort.clear()
         self._thread = greenthread.spawn(
             self._run_loop, idle_for,
             initial_delay=initial_delay, stop_on_exception=stop_on_exception)
         self._thread.link(self._on_done)
         return self.done
 
+    # NOTE(bnemec): This is just a wrapper function we can mock so we aren't
+    # affected by other users of the StopWatch class.
+    def _elapsed(self, watch):
+        return watch.elapsed()
+
     def _run_loop(self, idle_for_func,
                   initial_delay=None, stop_on_exception=True):
         kind = self._KIND
@@ -194,7 +151,7 @@ class LoopingCallBase(object):
                 watch.stop()
                 if not self._running:
                     break
-                idle = idle_for_func(result, watch.elapsed())
+                idle = idle_for_func(result, self._elapsed(watch))
                 LOG.trace('%(kind)s %(func_name)r sleeping '
                           'for %(idle).02f seconds',
                           {'func_name': func_name, 'idle': idle,
